import matplotlib.pyplot as plt
import numpy as np

def plot_raw_histogram(config_path: str, data_path: str) -> None:
    data = np.genfromtxt(data_path, dtype=np.int64, skip_header=1, delimiter='\n')
    print(data)
    plt.plot(data)
    plt.xlabel("bin")
    plt.ylabel("count")
    plt.show()

def plot_raw_histograms(config_path: str, data_path_1: str, data_path_2: str) -> None:
    fig, axs = plt.subplots(2, 1)
    data_1 = np.genfromtxt(data_path_1, dtype=np.int64, skip_header=1, delimiter='\n')
    data_2 = np.genfromtxt(data_path_2, dtype=np.int64, skip_header=1, delimiter='\n')
    x_values = (76.8/0.4 + np.arange(0, len(data_1))) * 0.4 
    axs[0].plot(x_values, data_1, color = "blue")
    axs[0].set_xlabel("$\Delta t$ (ns)")
    axs[0].set_ylabel("count")
    axs[0].set_xlim(76.8, (4096 + 76.8/0.4)*0.4)
    axs[0].set_xticks(np.arange(100, 1800, 100), [str(n) for n in np.arange(100, 1800, 100)])
    axs[0].set_title("CHN1, 10 MHz fast NIM")
    axs[1].plot(data_2, color = "skyblue")
    axs[1].set_xlabel("bin")
    axs[1].set_ylabel("count")
    axs[1].set_xlim(0, 4096)
    axs[1].set_title("CHN2, 10 MHz $V_{pp} = 1 V$")
    print("Sum CHN1", data_1.sum())
    print("Max CHN1", data_1.max())
    print("Sum CHN2", data_2.sum())
    print("Max CHN2", data_2.max())
    plt.show()